//LabPlot : GraphListView.h

#ifndef GRAPHLISTVIEW_H
#define GRAPHLISTVIEW_H

#include <klocale.h>
#include <klistview.h>

class GraphListView: public KListView
{
	Q_OBJECT
public:
	GraphListView(QWidget *p);
	// 7 normal columns
	void showZ() { if(columns()<8) addColumn(i18n("Z Range")); }
	void showT() { if(columns()<9) addColumn(i18n("T Range")); }
};

#endif //GRAPHLISTVIEW_H
